@@ -244,8 +244,7 @@ sub escape {
 # cookies and HTTP headers.  (They differ, unfortunately.)
 # Thanks to Mark Fisher for this.
 sub expires {
-    my($time,$format) = @_;
-    $format ||= 'http';
+    my $time = shift;
 
     my(@MON)=qw/Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec/;
     my(@WDAY) = qw/Sun Mon Tue Wed Thu Fri Sat/;
@@ -254,13 +253,9 @@ sub expires {
     $time = expire_calc($time);
     return $time unless $time =~ /^\d+$/;
 
-    # make HTTP/cookie date string from GMT'ed time
-    # (cookies use '-' as date separator, HTTP uses ' ')
-    my($sc) = ' ';
-    $sc = '-' if $format eq "cookie";
     my($sec,$min,$hour,$mday,$mon,$year,$wday) = gmtime($time);
     $year += 1900;
-    return sprintf("%s, %02d$sc%s$sc%04d %02d:%02d:%02d GMT",
+    return sprintf("%s, %02d %s %04d %02d:%02d:%02d GMT",
                    $WDAY[$wday],$mday,$MON[$mon],$year,$hour,$min,$sec);
 }
 
